@@ -1,4 +1,4 @@
-use Package::Alias 'Config::IOD' => 'Config::INI::OnDrugs';
+use Package::Alias 'Config::IOD' => 'Config::Ini::OnDrugs';
 package Config::IOD; # to make PodWeaver happy
 1;
 #ABSTRACT: Alias for Config::Ini::OnDrugs
@@ -12,7 +12,7 @@ Config::IOD - Alias for Config::Ini::OnDrugs
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 AUTHOR
 
